==> nat_mixpanel-0.0.19.tar.gz: android/src/main/java/com/exit/mixpanel/MixpanelPlugin.java <==
package com.exit.mixpanel;

import android.app.Application;
import android.content.Context;
import android.util.Log;

import com.mixpanel.android.mpmetrics.MixpanelAPI;


import org.json.JSONException;
import org.json.JSONObject;

import java.util.Map;

import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.MethodChannel.MethodCallHandler;
import io.flutter.plugin.common.MethodChannel.Result;
import io.flutter.plugin.common.PluginRegistry.Registrar;


public class MixpanelPlugin extends Application implements MethodCallHandler  {
    MixpanelAPI mixpanel;

    public static void registerWith(Registrar registrar) {
        final MethodChannel channel = new MethodChannel(registrar.messenger(), "mixpanel");
        channel.setMethodCallHandler(new MixpanelPlugin());
    }

    @Override
    public void onMethodCall(MethodCall call, Result result) {
        if (call.method.equals("init")) {
            Log.w("INIT", "mixpanel INITIALIZED");
            String token = call.argument("token");
            Context context =getBaseContext();
            Log.w("CONTEXT", (context==null) + "");
            mixpanel = MixpanelAPI.getInstance(getBaseContext(), token);
            Log.w("MIXPANEL", (mixpanel==null)+ " token " + token);
        } else if (call.method.equals("track")) {
            Map props = (Map) call.arguments;
            String eventName = (String) props.get("event");
            String properties = "";
            if (props.containsKey("properties"))
                properties = ((Map) props.get("properties")).toString();
            try {
                JSONObject pros = new JSONObject(properties);
                mixpanel.track(eventName, pros);
            } catch (JSONException ex) {
                mixpanel.track(eventName);
            }
        } else {
            result.notImplemented();
        }
    }
}

==> nat_mixpanel-0.0.21.tar.gz: android/src/main/java/com/exit/mixpanel/MixpanelPlugin.java <==
package com.exit.mixpanel;

import android.app.Application;
import android.content.Context;
import android.util.Log;

import com.mixpanel.android.mpmetrics.MixpanelAPI;


import org.json.JSONException;
import org.json.JSONObject;

import java.util.Map;

import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.MethodChannel.MethodCallHandler;
import io.flutter.plugin.common.MethodChannel.Result;
import io.flutter.plugin.common.PluginRegistry.Registrar;


public class MixpanelPlugin implements MethodCallHandler  {
    private MixpanelAPI mixpanel;
    private static Context context;

    public static void registerWith(Registrar registrar) {
        context = registrar.context();
        final MethodChannel channel = new MethodChannel(registrar.messenger(), "mixpanel");
        channel.setMethodCallHandler(new MixpanelPlugin());
    }

    @Override
    public void onMethodCall(MethodCall call, Result result) {
        if (call.method.equals("init")) {
            Log.w("INIT", "mixpanel INITIALIZED");
            String token = call.argument("token");
            Log.w("CONTEXT", (context==null) + "");
            mixpanel = MixpanelAPI.getInstance(context, token);
            Log.w("MIXPANEL", (mixpanel==null)+ " token " + token);
        } else if (call.method.equals("track")) {
            Map props = (Map) call.arguments;
            String eventName = (String) props.get("event");
            String properties = "";
            if (props.containsKey("properties"))
                properties = ((Map) props.get("properties")).toString();
            try {
                JSONObject pros = new JSONObject(properties);
                mixpanel.track(eventName, pros);
            } catch (JSONException ex) {
                mixpanel.track(eventName);
            }
        } else {
            result.notImplemented();
        }
    }
}
